plane_drone::config

Struct DroneConfig

pub struct DroneConfig {
    pub drone_id: Option<DroneId>,
    pub db_path: PathBuf,
    pub cluster_domain: String,
    pub nats: Option<NatsConnectionSpec>,
    pub cert: Option<KeyCertPathPair>,
    pub acme: Option<AcmeConfiguration>,
    pub agent: Option<AgentOptions>,
    pub proxy: Option<ProxyOptions>,
}

Fields

drone_id: Option<DroneId>

Unique string used to identify this drone. If not provided, a UUID is generated.

db_path: PathBuf

Path to use for the sqlite3 database through which the agent and proxy share a persisted state.

cluster_domain: String

The domain to which this drone belongs.

nats: Option<NatsConnectionSpec>

How to connect to NATS. Required by agent and certificate refresh.

cert: Option<KeyCertPathPair>

Paths to certificate and private key files. Required by proxy and certificate refresh.

acme: Option<AcmeConfiguration>

Settings for ACME certificate refresh. If not provided, certificates are not refreshed by this drone process.

agent: Option<AgentOptions>

Settings for the agent. If not provided, the agent does not run in this drone process.

proxy: Option<ProxyOptions>

Settings for the proxy. If not provided, the proxy does not run in this drone process.