pub struct KeyCertPathPair {
pub key_path: PathBuf,
pub cert_path: PathBuf,
}Fields
key_path: PathBufcert_path: PathBufImplementations
Sourceimpl KeyCertPathPair
impl KeyCertPathPair
pub fn load_certified_key(&self) -> Result<CertifiedKey>
Sourcepub fn parent_paths(&self) -> Vec<PathBuf>
pub fn parent_paths(&self) -> Vec<PathBuf>
Return a vector of directories that we should listen for filesystem events on.
If the key and certificate are in the same directory, this will be a one-element vector with just that directory. If the key and certificate are in different directories, this will be a two-element vector with both directories.
We listen to the parent directories rather than the files themselves because the files themselves may not exist when the server is started.